@@ -46,6 +46,7 @@ Components.utils.import("resource://app/modules/fileHelper.jsm");
 Components.utils.import("resource://app/modules/l10nHelper.jsm");
 Components.utils.import("resource://app/modules/handlersManager.jsm");
 Components.utils.import("resource://app/modules/screens.jsm");
+Components.utils.import("resource://app/modules/fileChanges.jsm");
 
 const kHTML_TRANSITIONAL = "resource://app/res/html_transitional.html";
 const kHTML_STRICT = "resource://app/res/html_strict.html";
@@ -53,7 +54,7 @@ const kXHTML_TRANSITIONAL = "resource://app/res/xhtml_transitional.xhtml";
 const kXHTML_STRICT = "resource://app/res/xhtml_strict.xhtml";
 const kHTML5 = "resource://app/res/html5.html";
 const kXHTML5 = "resource://app/res/xhtml5.xhtml";
-//@line 51 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 52 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 // implements nsIObserver
 var gEditorDocumentObserver =
@@ -126,7 +127,7 @@ var gEditorDocumentObserver =
           return; 
 
         // Set window title
-        UpdateWindowTitle();
+        gDialog.tabeditor.selectedTab.label = UpdateWindowTitle();
         UpdateTabHTMLDialect(editor)
 
         window.content.focus();
@@ -281,13 +282,65 @@ var BlueGriffonPrefsObserver = {
   }
 };
 
-//@line 53 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+
+const nsIDCW = Components.interfaces.nsIDOMChromeWindow;
+var gLastWindowState = -1;
+
+function onSizeModeChange()
+{
+  var badger = Components.classes["@disruptive-innovations.com/osintegration/badger;1"]
+                         .createInstance(Components.interfaces.diIOSIntegration);
+  var wm = Services.wm;
+  var hidden = wm.getMostRecentWindow("hidden-main");
+  var enumerator = wm.getEnumerator( "" );
+  switch (window.windowState) {
+    case nsIDCW.STATE_MINIMIZED:
+      {
+        // minified
+        gLastWindowState = window.windowState;
+        while ( enumerator.hasMoreElements() )
+        {
+          var win = enumerator.getNext().QueryInterface(Components.interfaces.nsIDOMWindow);
+          if (win.opener
+              && win.document.documentElement.id != "Bluegriffon"
+              && (win.opener == window || win.opener.document.documentElement.id == "hidden-window")) {
+            var baseWindow = win.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+                                   .getInterface(Components.interfaces.nsIWebNavigation)
+                                   .QueryInterface(Components.interfaces.nsIBaseWindow);
+            badger.show(baseWindow, false);
+          }
+        }
+      }
+      break;
+    default:
+      if (gLastWindowState == nsIDCW.STATE_MINIMIZED) {
+        // raised
+        gLastWindowState = -1;
+        while ( enumerator.hasMoreElements() )
+        {
+          var win = enumerator.getNext().QueryInterface(Components.interfaces.nsIDOMWindow);
+          if (win.opener
+              && win.document.documentElement.id != "Bluegriffon"
+              && (win.opener == window || win.opener.document.documentElement.id == "hidden-window")) {
+            var baseWindow = win.QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+                                   .getInterface(Components.interfaces.nsIWebNavigation)
+                                   .QueryInterface(Components.interfaces.nsIBaseWindow);
+            badger.show(baseWindow, true);
+          }
+        }
+      }
+      break;
+  }
+}
+
+//@line 54 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 Components.utils.import("resource://gre/modules/Services.jsm");
 Components.utils.import("resource://app/modules/urlHelper.jsm");
 Components.utils.import("resource://app/modules/editorHelper.jsm");
 Components.utils.import("resource://app/modules/bgQuit.jsm");
 Components.utils.import("resource://gre/modules/AddonManager.jsm");
+Components.utils.import("resource://gre/modules/fileChanges.jsm");
 
 var gContentWindow = null;
 
@@ -333,6 +386,7 @@ function Startup()
   BGUpdateManager.check();
   
   initLocalFontFaceMenu(gDialog.FontFacePopup);
+  initLocalFontFaceMenu(gDialog.inContextFontFacePopup);
 
   try {
     var pbi = Services.prefs.QueryInterface(Components.interfaces.nsIPrefBranchInternal);
@@ -347,11 +401,26 @@ function Startup()
   setTimeout(LoadLastTabs, 1000);
   BlueGriffonQuitHelper.init();
 
+  document.getElementById("tipoftheday").launch(null);
+
   AddonManager.getAddonByID("{f13b157f-b174-47e7-a34d-4815ddfdfeb8}",
     function(addon) { if(addon) document.getElementById("venkmanMenuitem").hidden = false; } );
 
   AddonManager.getAddonByID("inspector@mozilla.org",
     function(addon) { if(addon) document.getElementById("menu_inspector").hidden = false; } );
+
+  NotifierUtils.addNotifierCallback("selection_strict", BlueGriffon_lookForFileChanges, this);
+
+  window.addEventListener("sizemodechange", onSizeModeChange, false);
+}
+
+var gLookingForFileChangesTimeout = null;
+
+function BlueGriffon_lookForFileChanges() {
+  if (gLookingForFileChangesTimeout)
+    clearTimeout(gLookingForFileChangesTimeout);
+
+  gLookingForFileChangesTimeout = setTimeout(function() { FileChangeUtils.lookForChanges(); }, 500);
 }
 
 var gLastTabsArray;
@@ -456,10 +525,12 @@ function RestoreShortcuts()
     // no shortcut DB yet, do nothing
   }
 }
-//@line 55 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 56 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 function Shutdown()
 {
+  NotifierUtils.removeNotifierCallback("selection_strict", BlueGriffon_lookForFileChanges, this);
+
   try {
     var pbi = Services.prefs.QueryInterface(Components.interfaces.nsIPrefBranchInternal);
     pbi.removeObserver("bluegriffon.", BlueGriffonPrefsObserver, false);
@@ -494,7 +565,7 @@ function onClose()
     return true;
   }
   return false;
-}//@line 57 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+}//@line 58 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 function OpenLocation(aEvent, type)
@@ -664,7 +735,9 @@ function UpdateWindowTitle()
                                  .formatStringFromName("titleFormat",
                                                        [windowTitle, titleModifier],
                                                        2);
+    return windowTitle;                                                       
   } catch (e) { }
+  return "";
 }
 
 function onParagraphFormatChange(paraMenuList, commandID)
@@ -844,7 +917,7 @@ function onFontFaceChange(fontFaceMenuList, commandID)
   }
   else
   {
-    var menuPopup = document.getElementById("FontFacePopup");
+    var menuPopup = fontFaceMenuList.menupopup;
     var menuItems = menuPopup.childNodes;
     for (var i=0; i < menuItems.length; i++)
     {
@@ -1159,6 +1232,66 @@ function GetCurrentViewMode()
          "wysiwyg";
 }
 
+function onSourceChangeCallback(source)
+{
+  var doctype = EditorUtils.getCurrentDocument().doctype;
+  var systemId = doctype ? doctype.systemId : null;
+  var isXML = false;
+  switch (systemId) {
+    case "http://www.w3.org/TR/html4/strict.dtd": // HTML 4
+    case "http://www.w3.org/TR/html4/loose.dtd":
+    case null:
+      isXML = false;
+      break;
+    case "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd": // XHTML 1
+    case "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd":
+      isXML = true;
+      break;
+    case "":
+      isXML = (EditorUtils.getCurrentDocument().documentElement.getAttribute("xmlns") == "http://www.w3.org/1999/xhtml");
+      break;
+  }
+
+  var editorElement  = EditorUtils.getCurrentEditorElement();
+  var sourceIframe   = editorElement.previousSibling;
+  var sourceEditor   = sourceIframe.contentWindow.gEditor;
+  var sourceDocument = sourceIframe.contentWindow.document;
+
+  if (isXML) {
+    if (sourceEditor.lastErrorLine) {
+      var lineInfo = sourceEditor.lineInfo(sourceEditor.lastErrorLine - 1);
+      var markerClass = lineInfo.markerClass ? lineInfo.markerClass : "";
+      var markerClassArray = markerClass.split(" ");
+      markerClassArray.splice(markerClassArray.indexOf("error"), 1);
+      sourceEditor.setMarker(sourceEditor.lastErrorLine - 1, null, markerClassArray.join(" "));
+      sourceEditor.lastErrorLine = 0;
+    }
+    var xmlParser = new DOMParser();
+    try {
+      var doc = xmlParser.parseFromString(source, "text/xml");
+      if (doc.documentElement.nodeName == "parsererror") {
+        var message = doc.documentElement.firstChild.data.
+          replace( /Location\: chrome\:\/\/bluegriffon\/content\/xul\/bluegriffon.xul/g , ", ");
+        var error = doc.documentElement.lastChild.textContent;
+        var line = parseInt(doc.documentElement.getAttribute("line"));
+        var lineInfo = sourceEditor.lineInfo(line - 1);
+        var markerClass = lineInfo.markerClass ? lineInfo.markerClass : "";
+        var markerClassArray = markerClass.split(" ");
+        if (-1 == markerClassArray.indexOf("error"))
+          markerClassArray.push("error");
+        sourceEditor.setMarker(line - 1, null, markerClassArray.join(" "));
+        sourceEditor.lastErrorLine = line;
+
+        var visible = sourceEditor.visibleLines();
+        if (line >= visible.to || line < visible.from)
+          sourceEditor.setCursor(line - 1, 0);
+        return;
+      }
+    }
+    catch(e) {alert(e)}
+  }
+}
+
 function ToggleViewMode(aElement)
 {
   if (!aElement) // sanity case
@@ -1183,12 +1316,14 @@ function ToggleViewMode(aElement)
 
   gDialog.bespinToolbox1.hidden = true;
   gDialog.bespinToolbox2.hidden = true;
+  InContextHelper.hideInContextPanel();
   if (mode == "source")
   {
     gDialog.structurebar.style.visibility = "hidden";
     HandlersManager.hideAllHandlers();
+    gDialog.tabeditor.enableRulers(false);
 
-    var mimeType = EditorUtils.getCurrentDocument().contentType;
+    var mimeType = EditorUtils.getCurrentDocumentMimeType();
     const nsIDE = Components.interfaces.nsIDocumentEncoder;
     var encoder = Components.classes["@mozilla.org/layout/documentEncoder;1?type=" + mimeType]
                    .createInstance(nsIDE);
@@ -1202,9 +1337,19 @@ function ToggleViewMode(aElement)
 
     NotifierUtils.notify("beforeEnteringSourceMode");
     var source = encoder.encodeToString();
-    var bespinIframe = editorElement.previousSibling;
-    var bespinEditor = bespinIframe.contentWindow.gEditor;
-    bespinIframe.setUserData("oldSource", source, null);
+    var sourceIframe = editorElement.previousSibling;
+    var sourceEditor = sourceIframe.contentWindow.gEditor;
+    sourceIframe.contentWindow.gChangeCallback = onSourceChangeCallback;
+
+    var theme = null;
+    try {
+      theme = GetPrefs().getCharPref("bluegriffon.source.theme");
+    }
+    catch(e) {}
+    sourceIframe.contentWindow.installCodeMirror(BespinKeyPressCallback,
+                                                 theme,
+                                                 null,
+                                                 EditorUtils);
 
     var lastEditableChild = editor.document.body.lastChild;
     if (lastEditableChild.nodeType == Node.TEXT_NODE)
@@ -1215,42 +1360,43 @@ function ToggleViewMode(aElement)
 
     UnmarkSelection();
 
-    //bespinEditor.value = "";
-    bespinEditor.getSession().setValue(source);
-    bespinEditor.getSession().setUseWrapMode(false);
-    if (flags.value & nsIDE.OutputWrap) {
-      bespinEditor.setShowPrintMargin(true);
-      bespinEditor.setPrintMarginColumn(flags.maxColumnPref);
+    sourceEditor.setValue(source.replace( /\r\n/g, "\n").replace( /\r/g, "\n"));
+    /*if (flags.value & nsIDE.OutputWrap) {
+      sourceEditor.setShowPrintMargin(true);
+      sourceEditor.setPrintMarginColumn(flags.maxColumnPref);
     }
     else {
-      bespinEditor.setShowPrintMargin(false);
-    }
+      sourceEditor.setShowPrintMargin(false);
+    }*/
     NotifierUtils.notify("afterEnteringSourceMode");
     editorElement.parentNode.selectedIndex = 0;
 
-    MarkSelectionInAce(bespinEditor, source);
-
-    bespinIframe.focus();
-    bespinEditor.focus();
+    sourceIframe.focus();
+    sourceEditor.refresh();
+    sourceEditor.focus();
+    MarkSelectionInAce(sourceEditor, source);
+    sourceIframe.setUserData("oldSource", sourceEditor.getValue(), null);
   }
   else if (mode == "wysiwyg")
   {
     // Reduce the undo count so we don't use too much memory
     //   during multiple uses of source window 
     //   (reinserting entire doc caches all nodes)
-    var bespinIframe = editorElement.previousSibling;
-    var bespinEditor = bespinIframe.contentWindow.gEditor;
-    if (bespinEditor)
+    gDialog.tabeditor.enableRulers(true);
+
+    var sourceIframe = editorElement.previousSibling;
+    var sourceEditor = sourceIframe.contentWindow.gEditor;
+    if (sourceEditor)
     {
       NotifierUtils.notify("beforeLeavingSourceMode");
-      source = bespinEditor.getSession().getValue();
-      bespinEditor.blur();
-      var oldSource = bespinIframe.getUserData("oldSource"); 
+      source = sourceEditor.getValue();
+      //sourceEditor.blur();
+      var oldSource = sourceIframe.getUserData("oldSource"); 
       if (source != oldSource) {
         var doctype = EditorUtils.getCurrentDocument().doctype;
-        var publicId = doctype ? doctype.publicId : null;
+        var systemId = doctype ? doctype.systemId : null;
         var isXML = false;
-        switch (publicId) {
+        switch (systemId) {
           case "http://www.w3.org/TR/html4/strict.dtd": // HTML 4
           case "http://www.w3.org/TR/html4/loose.dtd":
           case null:
@@ -1389,7 +1535,7 @@ function doCloseTab(aTab)
   }
   window.updateCommands("style");
   NotifierUtils.notify("tabClosed");
-//@line 956 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1032 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 }
 
 function SetLocationDB()
@@ -1444,7 +1590,7 @@ function OpenPreferences()
   if (w)
     w.focus();
   else {
-    var features = "chrome,titlebar,toolbar,centerscreen,dialog=yes";
+    var features = "chrome,titlebar,toolbar,centerscreen,dialog=yes,resizable=yes";
     window.openDialog("chrome://bluegriffon/content/prefs/prefs.xul", "Preferences", features);
   }
 }
@@ -1655,7 +1801,6 @@ function OnDoubleClick(aEvent)
       cmdInsertKeygenCommand.doCommand();
       break;
     case "output":
-      cmdInsertOutputCommand.doCommand();
       break;
     case "progress":
       cmdInsertProgressCommand.doCommand();
@@ -1713,7 +1858,7 @@ function onBespinLineKeypress(aEvent, aElt)
 {
   if (aEvent.keyCode == 13) {
     var line = aElt.value;
-    EditorUtils.getCurrentSourceEditor().gotoLine(parseInt(line));
+    EditorUtils.getCurrentSourceEditor().setCursor(parseInt(line) - 1, 0);
     onBespinLineBlur(aElt);
     onBespinFocus(EditorUtils.getCurrentSourceEditorElement());
   }
@@ -1721,16 +1866,16 @@ function onBespinLineKeypress(aEvent, aElt)
       (aEvent.keyCode == 27 && !aEvent.which)) { // ESC key
     gDialog.bespinToolbox1.hidden = true;
     gDialog.bespinToolbox2.hidden = true;
+    EditorUtils.getCurrentSourceEditorElement().lastNeedle = null;
     EditorUtils.getCurrentSourceEditorElement().focus();
   }
 }
 
 function ToggleBespinFindCaseSensitivity()
 {
-  var bespinIframe = EditorUtils.getCurrentSourceEditorElement(); 
-  var selPoint = bespinIframe.getUserData("selPoint");
-  EditorUtils.getCurrentSourceEditor().setCursor(selPoint);
-  BespinFind(bespinIframe.getUserData("findLastDirection"));
+  var sourceIframe = EditorUtils.getCurrentSourceEditorElement(); 
+  var selPoint = sourceIframe.getUserData("selPoint");
+  BespinFind(sourceIframe.getUserData("findLastDirection"));
 }
 
 function BespinFind(aForward, aInitial)
@@ -1773,37 +1918,40 @@ function BespinFind(aForward, aInitial)
     return false;
   }
   else {
-    var bespinIframe = EditorUtils.getCurrentSourceEditorElement();
-    var bespinEditor = bespinIframe.contentWindow.gEditor;
-    bespinIframe.setUserData("findLastDirection", aForward, null);
+    var sourceIframe = EditorUtils.getCurrentSourceEditorElement();
+    var sourceEditor = sourceIframe.contentWindow.gEditor;
+    sourceIframe.setUserData("findLastDirection", aForward, null);
     var query = gDialog.bespinFindTextbox.value;
     var isCaseSensitive = gDialog.bespinFindCaseSensitive.checked;
-    var range = null;
-    if (aInitial) {
-      var selection = bespinEditor.getSession().getSelection();
-      if (!selection.isEmpty()) {
-        var r = selection.getRange();
-        var start = r.start;
-        selection.setSelectionRange({ start: { row: start.row, column: start.column },
-                                      end:   { row: start.row, column: start.column } });
-      }
-      range = bespinEditor.find(query, { backwards: false,
-                                         wrap: true,
-                                         caseSensitive: isCaseSensitive,
-                                         wholeWord: false,
-                                         regExp: false
-                              });
+    var found = false;
+    if (aInitial || !sourceEditor.lastNeedle) {
+      var selection = sourceEditor.getCursor(true);
+      sourceEditor.lastNeedle = sourceEditor.getSearchCursor(query, { line: selection.line, ch: selection.ch }, isCaseSensitive);
+      found = sourceEditor.lastNeedle.findNext();
     }
     else {
       if (aForward) {
-        range = bespinEditor.findNext();
+        found = sourceEditor.lastNeedle.findNext();
       }
       else {
-        range = bespinEditor.findPrevious();
+        found = sourceEditor.lastNeedle.findPrevious();
       }
     }
-  
-    if (!range) {
+
+    if (!found) { // maybe we hit the document's limits
+      if (aForward) {
+        sourceEditor.lastNeedle = sourceEditor.getSearchCursor(query, { line: 0, ch: 0 }, isCaseSensitive);
+        found = sourceEditor.lastNeedle.findNext();
+      }
+      else {
+        var line = sourceEditor.lineCount() - 1;
+        var lineProse = sourceEditor.getLine(line);
+        sourceEditor.lastNeedle = sourceEditor.getSearchCursor(query, { line: line, ch: lineProse.length -1 }, isCaseSensitive);
+        found = sourceEditor.lastNeedle.findPrevious();
+      }
+    }
+
+    if (!found) {
       //gDialog.bespinFindCaseSensitive.hidden = true;
       gDialog.bespinFindPrevious.hidden = true;
       gDialog.bespinFindNext.hidden = true;
@@ -1811,8 +1959,8 @@ function BespinFind(aForward, aInitial)
       gDialog.bespinToolbox2.hidden = true;
       return false;
     }
-    bespinEditor.getSession().getSelection().setSelectionRange(range, false);
 
+    sourceEditor.setSelection(sourceEditor.lastNeedle.from(), sourceEditor.lastNeedle.to());
     gDialog.bespinFindCaseSensitive.hidden = false;
     gDialog.bespinFindPrevious.hidden = false;
     gDialog.bespinFindNext.hidden = false;
@@ -1866,8 +2014,8 @@ function BespinKeyPressCallback(aEvent)
       case 120: // meta-x XXX
         {
           aEvent.preventDefault();
-          var bespinEditor = EditorUtils.getCurrentSourceEditor();
-          var selection = bespinEditor.selectedText;
+          var sourceEditor = EditorUtils.getCurrentSourceEditor();
+          var selection = sourceEditor.selectedText;
           var clipboardSvc = Components.classes["@mozilla.org/widget/clipboard;1"].
                              getService(Components.interfaces.nsIClipboard);
           var xferable = Components.classes["@mozilla.org/widget/transferable;1"].
@@ -1880,7 +2028,7 @@ function BespinKeyPressCallback(aEvent)
           clipboardSvc.setData(xferable, null, Components.interfaces.nsIClipboard.kGlobalClipboard);
         }
         if (aEvent.which == 120)
-          bespinEditor.selectedText = "";
+          sourceEditor.selectedText = "";
         break;*/
       default:
         break;
@@ -1891,11 +2039,14 @@ function BespinKeyPressCallback(aEvent)
 function BespinReplace()
 {
   if (GetCurrentViewMode() == "source") {
-    var bespinIframe = EditorUtils.getCurrentSourceEditorElement();
-    var bespinEditor = bespinIframe.contentWindow.gEditor;
-    var selection = bespinEditor.getSession().getSelection();
-    var r = selection.getRange();
-    bespinEditor.$tryReplace(r, gDialog.bespinReplaceTextbox.value)
+    var sourceIframe = EditorUtils.getCurrentSourceEditorElement();
+    var sourceEditor = sourceIframe.contentWindow.gEditor;
+    if (sourceEditor.lastNeedle && sourceEditor.lastNeedle.from() && sourceEditor.lastNeedle.to()) {
+      var end = sourceEditor.lastNeedle.to();
+      sourceEditor.lastNeedle.replace(gDialog.bespinReplaceTextbox.value);
+      sourceEditor.setCursor(end);
+      //sourceEditor.focus();
+    }
   }
   else
     ReplaceInWysiwyg();
@@ -1911,9 +2062,17 @@ function BespinReplaceAll()
 {
   var occurences = 0;
   if (GetCurrentViewMode() == "source") {
-    var bespinIframe = EditorUtils.getCurrentSourceEditorElement();
-    var bespinEditor = bespinIframe.contentWindow.gEditor;
-    occurences = bespinEditor.replaceAll(gDialog.bespinReplaceTextbox.value);
+    var sourceIframe = EditorUtils.getCurrentSourceEditorElement();
+    var sourceEditor = sourceIframe.contentWindow.gEditor;
+
+    var query = gDialog.bespinFindTextbox.value;
+    var isCaseSensitive = gDialog.bespinFindCaseSensitive.checked;
+    sourceEditor.lastNeedle = sourceEditor.getSearchCursor(query, { line: 0, ch: 0 }, isCaseSensitive);
+
+    while (sourceEditor.lastNeedle.findNext()) {
+      occurences++;
+      sourceEditor.lastNeedle.replace(gDialog.bespinReplaceTextbox.value);
+    }
   }
   else {
     var found = true;
@@ -1947,10 +2106,9 @@ function WysiwygShowFindBar()
     }
   }
   else {
-    var bespinIframe = EditorUtils.getCurrentSourceEditorElement();
-    var bespinEditor = bespinIframe.contentWindow.gEditor;
-    var selectionRange = bespinEditor.getSelectionRange();
-    var text = bespinEditor.getSession().getTextRange(selectionRange)
+    var sourceIframe = EditorUtils.getCurrentSourceEditorElement();
+    var sourceEditor = sourceIframe.contentWindow.gEditor;
+    var text = sourceEditor.getSelection();
     if (text) {
       gDialog.bespinFindTextbox.value = text;
       BespinFind(true, true);
@@ -2036,7 +2194,7 @@ function ReplaceInWysiwyg()
   return true;
 }
 
-//@line 1266 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1341 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 var AutoInsertTable = {
@@ -2113,7 +2271,10 @@ var AutoInsertTable = {
     var tableBody = doc.createElement("tbody");
     tableElement.appendChild(tableBody);
     tableElement.setAttribute("border", "1");
-    tableElement.setAttribute("width", "100%");
+    if (doc.doctype && doc.doctype.publicId == "") // html5
+      tableElement.setAttribute("style", "width: 100%");
+    else
+      tableElement.setAttribute("width", "100%");
     var firstCell = null;
     for (var i = 0; i < this.mRow; i++)
     {
@@ -2171,7 +2332,7 @@ var AutoInsertTable = {
     }
   }
 };
-//@line 1268 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1343 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 function AlignAllPanels()
@@ -2182,9 +2343,9 @@ function AlignAllPanels()
 
 function UpdatePanelsStatusInMenu()
 {
-//@line 1280 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1355 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   return;
-//@line 1283 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1358 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   var child = gDialog.beforeAllPanelsMenuseparator.nextSibling;
   while (child) {
     var panel = gDialog[child.getAttribute("panel")];
@@ -2199,9 +2360,9 @@ function UpdatePanelsStatusInMenu()
 
 function TogglePanel(aEvent)
 {
-//@line 1299 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1374 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   return;
-//@line 1302 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1377 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
   var menuitem = aEvent.originalTarget;
   if (!menuitem.hasAttribute("panel"))
     return;
@@ -2222,8 +2383,9 @@ function OnClick(aEvent)
 {
   // this is necessary to be able to select for instance video elements
   var target = aEvent.explicitOriginalTarget;
-  if (target && (target instanceof Components.interfaces.nsIDOMHTMLVideoElement ||
-                 target instanceof Components.interfaces.nsIDOMHTMLAudioElement)) {
+  if (target && (target instanceof Components.interfaces.nsIDOMHTMLVideoElement
+                 || target instanceof Components.interfaces.nsIDOMHTMLAudioElement
+                 || target instanceof Components.interfaces.nsIDOMHTMLSelectElement)) {
     EditorUtils.getCurrentEditor().selectElement(target);
   }
 }
@@ -2291,6 +2453,7 @@ function ToggleAllTagsMode()
   if (tab) {
     var editor = EditorUtils.getCurrentEditor();
     editor instanceof Components.interfaces.nsIEditorStyleSheets;
+    var scrollTop = editor.document.documentElement.scrollTop;
     if (tab.hasAttribute("alltags")) {
       tab.removeAttribute("alltags");
       editor.enableStyleSheet("chrome://bluegriffon/content/EditorAllTags.css", false);
@@ -2299,6 +2462,7 @@ function ToggleAllTagsMode()
       tab.setAttribute("alltags", "true");
       editor.enableStyleSheet("chrome://bluegriffon/content/EditorAllTags.css", true);
     }
+    editor.document.documentElement.scrollTop = scrollTop;
   }
 }
 
@@ -2402,7 +2566,7 @@ function IgnoreWord()
   sc.ignoreWord();
 }
 
-//@line 1503 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1581 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 function OpenCharInsertionDialog()
 {
   var w = null;
@@ -2416,7 +2580,7 @@ function OpenCharInsertionDialog()
    window.openDialog("chrome://bluegriffon/content/dialogs/insertChars.xul","_blank",
                      "chrome,modal=no,titlebar");
 }
-//@line 1517 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1595 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 
 var gDummySelectionStartNode = null;
@@ -2523,40 +2687,26 @@ function UnmarkSelection()
   }
 }
 
-function MarkSelectionInAce(aAceEditor)
+function MarkSelectionInAce(aSourceEditor)
 {
   const kBGBGBG = "--BG--";
 
-  var selection = aAceEditor.getSession().getSelection();
-  selection.setSelectionRange({ start: { row: 0, column: 0 },
-                                end:   { row: 0, column: 0 } });
+  aSourceEditor.setSelection( { line: 0, ch: 0 }, { line: 0, ch: 0 } );
 
-  var range = aAceEditor.find(kBGBGBG, { backwards: false,
-                                         wrap: true,
-                                         caseSensitive: true,
-                                         wholeWord: false,
-                                         regExp: false
-                              });
-  var startRow    = range.start.row;
-  var startColumn = range.start.column;
-  selection.setSelectionRange({ start: { row: 0, column: 0 },
-                                end:   { row: 0, column: 0 } });
-  aAceEditor.replace("");
+  var searchCursor = aSourceEditor.getSearchCursor(kBGBGBG, { line: 0, ch: 0 }, true);
+  searchCursor.findNext();
+  var startRow    = searchCursor.from().line;
+  var startColumn = searchCursor.from().ch;
+  searchCursor.replace("");
 
-  var range = aAceEditor.find(kBGBGBG, { backwards: false,
-                                         wrap: true,
-                                         caseSensitive: true,
-                                         wholeWord: false,
-                                         regExp: false
-                              });
-  var endRow      = range.start.row;
-  var endColumn   = range.start.column;
-  aAceEditor.replace("");
+  searchCursor = aSourceEditor.getSearchCursor(kBGBGBG, { line: 0, ch: 0 }, true);
+  searchCursor.findNext();
+  var endRow      = searchCursor.from().line;
+  var endColumn   = searchCursor.from().ch;
+  searchCursor.replace("");
 
-  aAceEditor.gotoLine(startRow);
-  selection.setSelectionRange({ start: { row: startRow, column: startColumn },
-                                end:   { row: endRow,   column: endColumn } });
-  aAceEditor.reset();
+  aSourceEditor.clearHistory();
+  aSourceEditor.setSelection( { line: startRow, ch: startColumn }, { line: endRow, ch: endColumn } );
 }
 
 function FillAceThemesMenupopup()
@@ -2582,7 +2732,7 @@ function UseAceTheme(aEvent)
   aceIframe.contentWindow.useTheme(theme);
 }
 
-//@line 1715 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
+//@line 1779 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/bluegriffon.js"
 
 function SaveCurrentTabLocation()
 {
@@ -2618,3 +2768,114 @@ function CreateOrUpdateTableOfContents()
   window.openDialog("chrome://bluegriffon/content/dialogs/insertTOC.xul","_blank",
                     "chrome,modal,titlebar");
 }
+
+function ShowUpdates()
+{
+  // copied from checkForUpdates in mozilla/browser/base/content/utilityOverlay.js
+  var um =
+    Components.classes["@mozilla.org/updates/update-manager;1"]
+              .getService(Components.interfaces.nsIUpdateManager);
+  var prompter =
+    Components.classes["@mozilla.org/updates/update-prompt;1"]
+              .createInstance(Components.interfaces.nsIUpdatePrompt);
+
+  // If there's an update ready to be applied, show the "Update Downloaded"
+  // UI instead and let the user know they have to restart the browser for
+  // the changes to be applied.
+  if (um.activeUpdate && um.activeUpdate.state == "pending")
+    prompter.showUpdateDownloaded(um.activeUpdate);
+  else
+    prompter.checkForUpdates();
+}
+
+function CheckForUpdates(aPopup)
+{
+  var item = aPopup.querySelector("#menu_updates");
+  if (item) {
+    // copied from buildHelpMenu in mozilla/browser/base/content/utilityOverlay.js
+    var updates =
+      Components.classes["@mozilla.org/updates/update-service;1"]
+                .getService(Components.interfaces.nsIApplicationUpdateService);
+    var um =
+      Components.classes["@mozilla.org/updates/update-manager;1"]
+                .getService(Components.interfaces.nsIUpdateManager);
+
+    // Disable the UI if the update enabled pref has been locked by the
+    // administrator or if we cannot update for some other reason
+    var checkForUpdates = item;
+    var canCheckForUpdates = updates.canCheckForUpdates;
+    checkForUpdates.setAttribute("disabled", !canCheckForUpdates);
+    if (!canCheckForUpdates)
+      return;
+
+    var strings =
+      Services.strings
+              .createBundle("chrome://bluegriffon/locale/updates.properties");
+    var activeUpdate = um.activeUpdate;
+
+    // If there's an active update, substitute its name into the label
+    // we show for this item, otherwise display a generic label.
+    function getStringWithUpdateName(key) {
+      if (activeUpdate && activeUpdate.name)
+        return strings.formatStringFromName(key, [activeUpdate.name], 1);
+      return strings.formatStringFromName(key, ["..."], 1);
+    }
+
+    // By default, show "Check for Updates..."
+    var key = "update.checkInsideButton";
+    if (activeUpdate) {
+      switch (activeUpdate.state) {
+      case "downloading":
+        // If we're downloading an update at present, show the text:
+        // "Downloading Instantbird x.x..." otherwise we're paused, and show
+        // "Resume Downloading Instantbird x.x..."
+        key = updates.isDownloading ? "update.checkInsideButton" : "update.resumeButton";
+        break;
+      case "pending":
+        // If we're waiting for the user to restart, show: "Apply Downloaded
+        // Updates Now..."
+        key = "update.restart.applyButton";
+        break;
+      }
+    }
+    checkForUpdates.label     = getStringWithUpdateName(key + ".label");
+    checkForUpdates.accessKey = strings.GetStringFromName(key + ".accesskey");
+    if (um.activeUpdate && updates.isDownloading)
+      checkForUpdates.setAttribute("loading", "true");
+    else
+      checkForUpdates.removeAttribute("loading");
+  }
+}
+
+function onFontColorChange()
+{
+  var commandNode = document.getElementById("cmd_fontColor");
+  if (commandNode)
+  {
+    var color = commandNode.getAttribute("state");
+    var button = document.getElementById("inContextTextColorColorpicker");
+    if (button)
+    {
+      // No color set - get color set on page or other defaults
+      if (!color || color == "mixed")
+        color = "transparent";
+      button.color = color;
+    }
+  }
+}
+
+function onBackgroundColorChange()
+{
+  var commandNode = document.getElementById("cmd_highlight");
+  if (commandNode)
+  {
+    var color = commandNode.getAttribute("state");
+    var button = document.getElementById("inContextBackgroundColorColorpicker");
+    if (button)
+    {
+      if (!color || color == "mixed")
+        color = "transparent";
+      button.color = color;
+    }
+  }
+}
