@@ -152,6 +152,8 @@ var ComposerCommands = {
         case "cmd_align":
         case "cmd_fontFace":
         case "cmd_class":
+        case "cmd_fontColor":
+        case "cmd_highlight":
         case "cmd_id":
         case "cmd_ariaRole":
           this.pokeMultiStateUI(command, params);
@@ -312,11 +314,13 @@ var ComposerCommands = {
     commandTable.registerCommand("cmd_table",                cmdInsertOrEditTableCommand);
     commandTable.registerCommand("cmd_editTable",            bgEditTableCommand);
     commandTable.registerCommand("cmd_SelectTable",          bgSelectTableCommand);
+    commandTable.registerCommand("cmd_SelectTableCaption",   bgSelectTableCaptionCommand);
     commandTable.registerCommand("cmd_SelectRow",            bgSelectTableRowCommand);
     commandTable.registerCommand("cmd_SelectColumn",         bgSelectTableColumnCommand);
     commandTable.registerCommand("cmd_SelectCell",           bgSelectTableCellCommand);
     commandTable.registerCommand("cmd_SelectAllCells",       bgSelectAllTableCellsCommand);
     commandTable.registerCommand("cmd_InsertTable",          bgInsertTableCommand);
+    commandTable.registerCommand("cmd_InsertTableCaption",   bgInsertTableCaptionCommand);
     commandTable.registerCommand("cmd_InsertRowAbove",       bgInsertTableRowAboveCommand);
     commandTable.registerCommand("cmd_InsertRowBelow",       bgInsertTableRowBelowCommand);
     commandTable.registerCommand("cmd_InsertColumnBefore",   bgInsertTableColumnBeforeCommand);
@@ -324,6 +328,7 @@ var ComposerCommands = {
     commandTable.registerCommand("cmd_InsertCellBefore",     bgInsertTableCellBeforeCommand);
     commandTable.registerCommand("cmd_InsertCellAfter",      bgInsertTableCellAfterCommand);
     commandTable.registerCommand("cmd_DeleteTable",          bgDeleteTableCommand);
+    commandTable.registerCommand("cmd_DeleteTableCaption",   bgDeleteTableCaptionCommand);
     commandTable.registerCommand("cmd_DeleteRow",            bgDeleteTableRowCommand);
     commandTable.registerCommand("cmd_DeleteColumn",         bgDeleteTableColumnCommand);
     commandTable.registerCommand("cmd_DeleteCell",           bgDeleteTableCellCommand);
@@ -388,8 +393,6 @@ var ComposerCommands = {
     commandTable.registerCommand("cmd_bgfind",      cmdBgFindCommand);
     commandTable.registerCommand("cmd_replace",     cmdBgFindCommand);
 
-    commandTable.registerCommand("cmd_stylesheets", cmdStylesheetsCommand);
-
     commandTable.registerCommand("cmd_span",        cmdSpanCommand);
 
     commandTable.registerCommand("cmd_pageProperties", cmdPagePropertiesCommand);
@@ -442,6 +445,13 @@ var ComposerCommands = {
   {
     NotifierUtils.notify("selection_strict", aElement, aOneElementSelected);
 
+    if (!EditorUtils.getCurrentEditor().selection.isCollapsed) {
+      InContextHelper.showInContextPanel(aElement);
+    }
+    else {
+      InContextHelper.hideInContextPanel();
+    }
+
     var path = "";
     var node = aElement;
     while (node && node.nodeType == Node.ELEMENT_NODE) {
@@ -597,9 +607,8 @@ var cmdSave =
       var docUrl = EditorUtils.getDocumentUrl();
       return EditorUtils.isDocumentEditable()
               && (GetCurrentViewMode() == "source"
-                  || (EditorUtils.isDocumentModified()
-                      || UrlUtils.isUrlOfBlankDocument(docUrl)
-                      || UrlUtils.getScheme(docUrl) != "file"));
+                  || EditorUtils.isDocumentModified()
+                  || UrlUtils.isUrlOfBlankDocument(docUrl));
     } catch (e) {return false;}
   },
   
@@ -615,9 +624,9 @@ var cmdSave =
         var mode = GetCurrentViewMode();
         if (mode == "source") {
           var editorElement = EditorUtils.getCurrentEditorElement();
-          var bespinIframe = editorElement.previousSibling;
-          var bespinEditor = bespinIframe.contentWindow.gEditor;
-          var source = bespinEditor.getSession().getValue();
+          var sourceIframe = editorElement.previousSibling;
+          var sourceEditor = sourceIframe.contentWindow.gEditor;
+          var source = sourceEditor.getValue();
 
           result = FileUtils.saveSourceDocument(source,
                      UrlUtils.isUrlOfBlankDocument(EditorUtils.getDocumentUrl()),
@@ -631,6 +640,7 @@ var cmdSave =
                      EditorUtils.getCurrentDocumentMimeType());
         }
         window.content.focus();
+        window.updateCommands("style");
         if (result)
           StoreUrlInLocationDB(EditorUtils.getDocumentUrl());
       }
@@ -658,9 +668,9 @@ var cmdSaveAs =
         var mode = GetCurrentViewMode();
         if (mode == "source") {
           var editorElement = EditorUtils.getCurrentEditorElement();
-          var bespinIframe = editorElement.previousSibling;
-          var bespinEditor = bespinIframe.contentWindow.gEditor;
-          var source = bespinEditor.getSession().getValue();
+          var sourceIframe = editorElement.previousSibling;
+          var sourceEditor = sourceIframe.contentWindow.gEditor;
+          var source = sourceEditor.getValue();
 
           result = FileUtils.saveSourceDocument(source,
                      true,
@@ -1172,6 +1182,38 @@ var cmdStructurePreviousCommand =
 };
 //-----------------------------------------------------------------------------------
 
+function ApplyToNodesArray(aFunctor, aEditor)
+{
+  var nodes = [], node;
+  if (aEditor
+      && aEditor.selection.rangeCount > 1) {
+    var selection = aEditor.selection;
+    var count = selection.rangeCount;
+    for (var i = 0; i < count; i++) {
+      var range = selection.getRangeAt(i);
+      if (range.startContainer == range.endContainer
+          && range.startOffset + 1 == range.endOffset
+          && range.startContainer.nodeType == Node.ELEMENT_NODE) {
+        node = range.startContainer.childNodes[range.startOffset];
+      }
+      else
+        node = selection.getRangeAt(i).commonAncestorContainer;
+      nodes.push(node);
+    }
+  }
+  else
+    nodes.push(EditorUtils.getSelectionContainer().node);
+
+  aEditor.beginTransaction();
+  for (var k = 0 ; k < nodes.length; k++) {
+    node = nodes[k];
+    aFunctor(node, arguments);
+  }
+  aEditor.endTransaction();
+
+  return nodes;
+}
+
 var cmdClass =
 {
   isCommandEnabled: function(aCommand, dummy)
@@ -1204,37 +1246,47 @@ var cmdClass =
   doCommandParams: function(aCommandName, aParams, aRefCon)
   {
     var className = aParams.getCStringValue("state_attribute");
-    var node = EditorUtils.getSelectionContainer().node;
 
-    if (className) {
-      var classes = node.classList;
-  
-      var newList = className;
-      if (classes)
-      {
-        var found = false;
-        newList = [];
-        for (var i = 0; i < classes.length; i++)
+    function functor(aNode) {
+      var editor = arguments[1][1];
+      var cn = arguments[1][2];
+
+      if (cn) {
+        var classes = aNode.classList;
+    
+        var newList = cn;
+        if (classes)
         {
-          if (classes[i] == className)
-            found = true;
-          else
-          newList.push(classes[i]);;
+          var found = false;
+          newList = [];
+          for (var i = 0; i < classes.length; i++)
+          {
+            if (classes[i] == cn)
+              found = true;
+            else
+            newList.push(classes[i]);;
+          }
+          if (!found)
+            newList.push(cn);
         }
-        if (!found)
-          newList.push(className);
+        if (newList.length)
+          editor.setAttribute(aNode, "class", newList.join(" "));
+        else
+          editor.removeAttribute(aNode, "class");
       }
-  
-      EditorUtils.getCurrentEditor().setAttribute(node, "class", newList.join(" "));
+      else
+        editor.removeAttribute(aNode, "class");
     }
-    else
-      EditorUtils.getCurrentEditor().removeAttribute(node, "class");
+
+    var nodes = ApplyToNodesArray(functor,
+                                  EditorUtils.getCurrentEditor(),
+                                  className);
+
     // be kind with the rest of the world
-    NotifierUtils.notify("selection", node, false);
+    NotifierUtils.notify("selection", nodes[0], false);
   }
 };
 
-
 var cmdId =
 {
   isCommandEnabled: function(aCommand, dummy)
@@ -1331,14 +1383,23 @@ var cmdAriaRole =
   doCommandParams: function(aCommandName, aParams, aRefCon)
   {
     var role = aParams.getCStringValue("state_attribute");
-    var node = EditorUtils.getSelectionContainer().node;
 
-    if (role)
-      EditorUtils.getCurrentEditor().setAttribute(node, "role", role);
-    else
-      EditorUtils.getCurrentEditor().removeAttribute(node, "role");
+    function functor(aNode) {
+      var editor = arguments[1][1];
+      var r = arguments[1][2];
+      if (r)
+        editor.setAttribute(aNode, "role", r);
+      else
+        editor.removeAttribute(aNode, "role");
+    }
+
+    var nodes = ApplyToNodesArray(functor,
+                                  EditorUtils.getCurrentEditor(),
+                                  role);
+
     // be kind with the rest of the world
-    NotifierUtils.notify("selection", node, false);
+    NotifierUtils.notify("selection", nodes[0], false);
+
   }
 };
 
@@ -2062,6 +2123,36 @@ var bgSelectTableCommand =
   }
 };
 
+var bgSelectTableCaptionCommand =
+{
+  isCommandEnabled: function(aCommand, dummy)
+  {
+    var element = EditorUtils.getObjectForProperties(["table"]);
+    if (element &&
+        EditorUtils.getCurrentEditorElement() &&
+        EditorUtils.isDocumentEditable() &&
+        EditorUtils.isEditingRenderedHTML() &&
+        GetCurrentViewMode() == "wysiwyg") {
+      // but do we already have a caption?
+      return  (element.firstElementChild
+               && element.firstElementChild.nodeName == "caption");
+    }
+    return false;
+  },
+
+  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
+  doCommandParams: function(aCommand, aParams, aRefCon) {},
+
+  doCommand: function(aCommand)
+  {
+    var element = EditorUtils.getObjectForProperties(["table"]);
+    try {
+      EditorUtils.getCurrentEditor().selectElement(element.firstElementChild);
+    } catch(e) {}
+    window.content.focus();
+  }
+};
+
 var bgSelectTableRowCommand =
 {
   isCommandEnabled: function(aCommand, dummy)
@@ -2158,6 +2249,40 @@ var bgSelectAllTableCellsCommand =
   }
 };
 
+var bgInsertTableCaptionCommand =
+{
+  isCommandEnabled: function(aCommand, dummy)
+  {
+    var element = EditorUtils.getObjectForProperties(["table"]);
+    if (element &&
+        EditorUtils.getCurrentEditorElement() &&
+        EditorUtils.isDocumentEditable() &&
+        EditorUtils.isEditingRenderedHTML() &&
+        GetCurrentViewMode() == "wysiwyg") {
+      // but do we already have a caption?
+      return  (!element.firstElementChild
+               || element.firstElementChild.nodeName != "caption");
+    }
+    return false;
+  },
+
+  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
+  doCommandParams: function(aCommand, aParams, aRefCon) {},
+
+  doCommand: function(aCommand)
+  {
+    var element = EditorUtils.getObjectForProperties(["table"]);
+    try {
+      var caption = EditorUtils.getCurrentEditor().createElementWithDefaults("caption");
+      var brNode = EditorUtils.getCurrentDocument().createElement("br");
+      caption.appendChild(brNode);
+      EditorUtils.getCurrentEditor().insertNode(caption, element, 0);
+      EditorUtils.getCurrentEditor().selectElement(brNode);
+    } catch(e) {}
+    window.content.focus();
+  }
+};
+
 var bgInsertTableRowAboveCommand =
 {
   isCommandEnabled: function(aCommand, dummy)
@@ -2326,6 +2451,36 @@ var bgDeleteTableCommand =
   }
 };
 
+var bgDeleteTableCaptionCommand =
+{
+  isCommandEnabled: function(aCommand, dummy)
+  {
+    var element = EditorUtils.getObjectForProperties(["table"]);
+    if (element &&
+        EditorUtils.getCurrentEditorElement() &&
+        EditorUtils.isDocumentEditable() &&
+        EditorUtils.isEditingRenderedHTML() &&
+        GetCurrentViewMode() == "wysiwyg") {
+      // but do we already have a caption?
+      return  (element.firstElementChild
+               && element.firstElementChild.nodeName == "caption");
+    }
+    return false;
+  },
+
+  getCommandStateParams: function(aCommand, aParams, aRefCon) {},
+  doCommandParams: function(aCommand, aParams, aRefCon) {},
+
+  doCommand: function(aCommand)
+  {
+    var element = EditorUtils.getObjectForProperties(["table"]);
+    try {
+      EditorUtils.getCurrentEditor().deleteNode(element.firstElementChild);
+    } catch(e) {}
+    window.content.focus();
+  }
+};
+
 function GetNumberOfContiguousSelectedRows()
 {
   var rows = 0;
@@ -2763,5 +2918,5 @@ var bgSelectTableColumnCommand =
 };
 
 
-//@line 511 "/home/glazou/trees/bg1.1/bluegriffon/base/content/bluegriffon/js/commands.js"
+//@line 521 "/home/glazou/trees/official/bluegriffon/base/content/bluegriffon/js/commands.js"
 
