@@ -1,4 +1,4 @@
-//@line 38 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 38 "/home/glazou/trees/official/toolkit/content/aboutSupport.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -15,11 +15,13 @@ const ELLIPSIS = Services.prefs.getComplexValue("intl.ellipsis",
 // under the "accessibility.*" branch.
 const PREFS_WHITELIST = [
   "accessibility.",
+  "browser.cache.",
   "browser.display.",
   "browser.fixup.",
   "browser.history_expire_",
   "browser.link.open_newwindow",
   "browser.places.",
+  "browser.sessionstore.",
   "browser.startup.homepage",
   "browser.tabs.",
   "browser.zoom.",
@@ -31,10 +33,12 @@ const PREFS_WHITELIST = [
   "general.useragent.",
   "gfx.",
   "html5.",
-  "layers.",
+  "image.mem.",
   "javascript.",
   "keyword.",
+  "layers.",
   "layout.css.dpi",
+  "media.",
   "mousewheel.",
   "network.",
   "permissions.default.image",
@@ -44,6 +48,8 @@ const PREFS_WHITELIST = [
   "print.",
   "privacy.",
   "security.",
+  "svg.",
+  "toolkit.startup.recent_crashes",
   "webgl."
 ];
 
@@ -74,6 +80,7 @@ window.onload = function () {
   populatePreferencesSection();
   populateExtensionsSection();
   populateGraphicsSection();
+  populateJavaScriptSection();
 }
 
 function populateExtensionsSection() {
@@ -213,14 +220,14 @@ function populateGraphicsSection() {
   if (gfxInfo) {
     let trGraphics = [];
     pushInfoRow(trGraphics, "adapterDescription", gfxInfo.adapterDescription);
-    pushInfoRow(trGraphics, "adapterVendorID", hexValueToString(gfxInfo.adapterVendorID));
-    pushInfoRow(trGraphics, "adapterDeviceID", hexValueToString(gfxInfo.adapterDeviceID));
+    pushInfoRow(trGraphics, "adapterVendorID", gfxInfo.adapterVendorID);
+    pushInfoRow(trGraphics, "adapterDeviceID", gfxInfo.adapterDeviceID);
     pushInfoRow(trGraphics, "adapterRAM", gfxInfo.adapterRAM);
     pushInfoRow(trGraphics, "adapterDrivers", gfxInfo.adapterDriver);
     pushInfoRow(trGraphics, "driverVersion", gfxInfo.adapterDriverVersion);
     pushInfoRow(trGraphics, "driverDate", gfxInfo.adapterDriverDate);
 
-//@line 296 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 303 "/home/glazou/trees/official/toolkit/content/aboutSupport.js"
 
     var webglrenderer;
     var webglenabled;
@@ -231,9 +238,9 @@ function populateGraphicsSection() {
       webglrenderer = false;
       webglenabled = false;
     }
-//@line 314 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 321 "/home/glazou/trees/official/toolkit/content/aboutSupport.js"
     var webglfeature = gfxInfo.FEATURE_WEBGL_OPENGL;
-//@line 316 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 323 "/home/glazou/trees/official/toolkit/content/aboutSupport.js"
     pushFeatureInfoRow(trGraphics, "webglRenderer", webglfeature, webglenabled, webglrenderer);
 
     appendChildren(graphics_tbody, trGraphics);
@@ -275,13 +282,13 @@ function populateGraphicsSection() {
     }
   }
 
-  let msg = acceleratedWindows + "/" + totalWindows;
+  let msg = acceleratedWindows;
   if (acceleratedWindows) {
-    msg += " " + mgrType;
+    msg += "/" + totalWindows + " " + mgrType;
   } else {
-//@line 364 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 371 "/home/glazou/trees/official/toolkit/content/aboutSupport.js"
     var feature = gfxInfo.FEATURE_OPENGL_LAYERS;
-//@line 366 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 373 "/home/glazou/trees/official/toolkit/content/aboutSupport.js"
     var errMsg = errorMessageForFeature(feature);
     if (errMsg)
       msg += ". " + errMsg;
@@ -295,17 +302,24 @@ function populateGraphicsSection() {
   ]);
 }
 
+function populateJavaScriptSection() {
+  let enabled = window.QueryInterface(Ci.nsIInterfaceRequestor)
+        .getInterface(Ci.nsIDOMWindowUtils)
+        .isIncrementalGCEnabled();
+  document.getElementById("javascript-incremental-gc").textContent = enabled ? "1" : "0";
+}
+
 function getPrefValue(aName) {
   let value = "";
   let type = Services.prefs.getPrefType(aName);
   switch (type) {
-    case Ci.nsIPrefBranch2.PREF_STRING:
+    case Ci.nsIPrefBranch.PREF_STRING:
       value = Services.prefs.getComplexValue(aName, Ci.nsISupportsString).data;
       break;
-    case Ci.nsIPrefBranch2.PREF_BOOL:
+    case Ci.nsIPrefBranch.PREF_BOOL:
       value = Services.prefs.getBoolPref(aName);
       break;
-    case Ci.nsIPrefBranch2.PREF_INT:
+    case Ci.nsIPrefBranch.PREF_INT:
       value = Services.prefs.getIntPref(aName);
       break;
   }
@@ -413,7 +427,7 @@ function createTextForElement(elem) {
   text = text.replace(/\n\n\n+/g, "\n\n");
 
   // Actual CR/LF pairs are needed for some Windows text editors.
-//@line 500 "/home/glazou/trees/bg1.1/toolkit/content/aboutSupport.js"
+//@line 514 "/home/glazou/trees/official/toolkit/content/aboutSupport.js"
 
   return text;
 }
