@@ -1,4 +1,4 @@
-//@line 40 "/home/glazou/trees/bg1.1/toolkit/components/viewconfig/content/config.js"
+//@line 40 "/home/glazou/trees/official/toolkit/components/viewconfig/content/config.js"
 
 const nsIPrefLocalizedString = Components.interfaces.nsIPrefLocalizedString;
 const nsISupportsString = Components.interfaces.nsISupportsString;
@@ -16,7 +16,7 @@ const nsAtomService_CONTRACTID = "@mozilla.org/atom-service;1";
 
 const gPromptService = Components.classes[nsPrompt_CONTRACTID].getService(nsIPromptService);
 const gPrefService = Components.classes[nsPrefService_CONTRACTID].getService(nsIPrefService);
-const gPrefBranch = gPrefService.getBranch(null).QueryInterface(Components.interfaces.nsIPrefBranch2);
+const gPrefBranch = gPrefService.getBranch(null);
 const gClipboardHelper = Components.classes[nsClipboardHelper_CONTRACTID].getService(nsIClipboardHelper);
 const gAtomService = Components.classes[nsAtomService_CONTRACTID].getService(nsIAtomService);
 
@@ -424,7 +424,8 @@ function FilterPrefs()
     gFilter = null;
   }
 
-  var prefCol = view.selection.currentIndex < 0 ? null : gPrefView[view.selection.currentIndex].prefCol;
+  var prefCol = (view.selection && view.selection.currentIndex < 0) ?
+                null : gPrefView[view.selection.currentIndex].prefCol;
   var oldlen = gPrefView.length;
   gPrefView = gPrefArray;
   if (gFilter) {
