@@ -1,4 +1,4 @@
-//@line 40 "/home/glazou/trees/bg1.1/toolkit/components/viewsource/content/viewSource.js"
+//@line 40 "/home/glazou/trees/official/toolkit/components/viewsource/content/viewSource.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -9,7 +9,8 @@ var gGoToLine = 0;
 
 [
   ["gBrowser",          "content"],
-  ["gViewSourceBundle", "viewSourceBundle"]
+  ["gViewSourceBundle", "viewSourceBundle"],
+  ["gContextMenu",      "viewSourceContextMenu"]
 ].forEach(function ([name, id]) {
   window.__defineGetter__(name, function () {
     var element = document.getElementById(id);
@@ -126,8 +127,7 @@ function viewSource(url)
 
       try {
         if (arg === true) {
-          var docCharset = gBrowser.docShell.QueryInterface(Ci.nsIDocCharset);
-          docCharset.charset = charset;
+          gBrowser.docShell.charset = charset;
         }
       } catch (ex) {
         // Ignore the failure and keep processing arguments...
@@ -674,12 +674,12 @@ function highlightSyntax()
   gPageLoader.loadPage(gPageLoader.currentDescriptor, gPageLoader.DISPLAY_NORMAL);
 }
 
+// Reload after change to character encoding or autodetection
+//
 // Fix for bug 136322: this function overrides the function in
 // browser.js to call PageLoader.loadPage() instead of BrowserReloadWithFlags()
-function BrowserSetForcedCharacterSet(aCharset)
+function BrowserCharsetReload()
 {
-  var docCharset = gBrowser.docShell.QueryInterface(Ci.nsIDocCharset);
-  docCharset.charset = aCharset;
   if (isHistoryEnabled()) {
     gPageLoader.loadPage(gPageLoader.currentDescriptor,
                          gPageLoader.DISPLAY_NORMAL);
@@ -688,23 +688,10 @@ function BrowserSetForcedCharacterSet(aCharset)
   }
 }
 
-// fix for bug #229503
-// we need to define BrowserSetForcedDetector() so that we can
-// change auto-detect options in the "View | Character Encoding" menu.
-// As with BrowserSetForcedCharacterSet(), call PageLoader.loadPage() 
-// instead of BrowserReloadWithFlags()
-function BrowserSetForcedDetector(doReload)
+function BrowserSetForcedCharacterSet(aCharset)
 {
-  gBrowser.documentCharsetInfo.forcedDetector = true; 
-  if (doReload)
-  {
-    if (isHistoryEnabled()) {
-      gPageLoader.loadPage(gPageLoader.currentDescriptor,
-                           gPageLoader.DISPLAY_NORMAL);
-    } else {
-      gBrowser.reloadWithFlags(Ci.nsIWebNavigation.LOAD_FLAGS_CHARSET_CHANGE);
-    }
-  }
+  gBrowser.docShell.charset = aCharset;
+  BrowserCharsetReload();
 }
 
 function BrowserForward(aEvent) {
@@ -773,3 +760,25 @@ function FillInHTMLTooltip(tipElement)
   return retVal;
 }
 
+function contextMenuShowing() {
+  var isLink = false;
+  var isEmail = false;
+  if (gContextMenu.triggerNode && gContextMenu.triggerNode.localName == 'a') {
+    if (gContextMenu.triggerNode.href.indexOf('view-source:') == 0)
+      isLink = true;
+    if (gContextMenu.triggerNode.href.indexOf('mailto:') == 0)
+      isEmail = true;
+  }
+  document.getElementById('context-copyLink').hidden = !isLink;
+  document.getElementById('context-copyEmail').hidden = !isEmail;
+}
+
+function contextMenuCopyLinkOrEmail() {
+  if (!gContextMenu.triggerNode)
+    return;
+
+  var href = gContextMenu.triggerNode.href;
+  var clipboard = Cc['@mozilla.org/widget/clipboardhelper;1'].
+                  getService(Ci.nsIClipboardHelper);
+  clipboard.copyString(href.substring(href.indexOf(':') + 1));
+}
