@@ -1,4 +1,4 @@
-//@line 45 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/content/downloads.js"
+//@line 45 "/home/glazou/trees/official/toolkit/mozapps/downloads/content/downloads.js"
 
 ////////////////////////////////////////////////////////////////////////////////
 //// Globals
@@ -16,6 +16,7 @@ let Cu = Components.utils;
 Cu.import("resource://gre/modules/XPCOMUtils.jsm");
 Cu.import("resource://gre/modules/DownloadUtils.jsm");
 Cu.import("resource://gre/modules/PluralForm.jsm");
+Cu.import("resource://gre/modules/Services.jsm");
 
 const nsIDM = Ci.nsIDownloadManager;
 
@@ -249,7 +250,7 @@ function openDownload(aDownload)
       dontAsk = !pref.getBoolPref(PREF_BDM_ALERTONEXEOPEN);
     } catch (e) { }
 
-//@line 307 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/content/downloads.js"
+//@line 308 "/home/glazou/trees/official/toolkit/mozapps/downloads/content/downloads.js"
 
     if (!dontAsk) {
       var strings = document.getElementById("downloadStrings");
@@ -433,7 +434,7 @@ function Startup()
     }
   }, false);
 
-//@line 495 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/content/downloads.js"
+//@line 496 "/home/glazou/trees/official/toolkit/mozapps/downloads/content/downloads.js"
 }
 
 function Shutdown()
@@ -489,11 +490,11 @@ let gDownloadObserver = {
         }
         break;
       case "browser-lastwindow-close-granted":
-//@line 551 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/content/downloads.js"
+//@line 552 "/home/glazou/trees/official/toolkit/mozapps/downloads/content/downloads.js"
         if (gDownloadManager.activeDownloadCount == 0) {
           setTimeout(gCloseDownloadManager, 0);
         }
-//@line 555 "/home/glazou/trees/bg1.1/toolkit/mozapps/downloads/content/downloads.js"
+//@line 556 "/home/glazou/trees/official/toolkit/mozapps/downloads/content/downloads.js"
         break;
     }
   }
@@ -682,6 +683,29 @@ var gDownloadDNDObserver =
   }
 }
 
+function pasteHandler() {
+  let trans = Cc["@mozilla.org/widget/transferable;1"].
+              createInstance(Ci.nsITransferable);
+  let flavors = ["text/x-moz-url", "text/unicode"];
+  flavors.forEach(trans.addDataFlavor);
+
+  Services.clipboard.getData(trans, Services.clipboard.kGlobalClipboard);
+
+  // Getting the data or creating the nsIURI might fail
+  try {
+    let data = {};
+    trans.getAnyTransferData({}, data, {});
+    let [url, name] = data.value.QueryInterface(Ci.nsISupportsString).data.split("\n");
+
+    if (!url)
+      return;
+
+    let uri = Services.io.newURI(url, null, null);
+
+    saveURL(uri.spec, name || uri.spec, null, true, true);
+  } catch (ex) {}
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 //// Command Updating and Command Handlers
 
